==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Ferramentas de Bloco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Exiba as ferramentas para Blocos</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Bloco</translatorcomment>
        <translation>&amp;Bloco</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaços no início ou no fim.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O nome do Bloco está vazio.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>O nome do Bloco não é válido.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Bloco &quot;%1&quot; já existe&lt;br&gt;e será substituído.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O Bloco já existe.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dados do Bloco</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Nome do Bloco:</translatorcomment>
        <translation>Nome do Bloco:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bloco 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Ferramentas de Bloco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Exiba as ferramentas para Blocos</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Bloco</translatorcomment>
        <translation>&amp;Bloco</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaços no início ou no fim.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O nome do Bloco está vazio.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>O nome do Bloco não é válido.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Bloco &quot;%1&quot; já existe&lt;br&gt;e será substituído.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O Bloco já existe.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dados do Bloco</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Nome do Bloco:</translatorcomment>
        <translation>Nome do Bloco:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bloco 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Layout</source>
        <translation type="vanished">Layout</translation>
    </message>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="vanished">Espaços no início ou no fim.</translation>
    </message>
    <message>
        <source>Layout name is empty.</source>
        <translation type="vanished">O nome do layout está vazio.</translation>
    </message>
    <message>
        <source>Layout name is invalid.</source>
        <translation type="vanished">O nome do layout não é válido.</translation>
    </message>
    <message>
        <source>Layout &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="vanished">Layout &quot;%1&quot; já existe&lt;br&gt;e será substituído.</translation>
    </message>
    <message>
        <source>Layout already exists.</source>
        <translation type="vanished">O layout já existe.</translation>
    </message>
    <message>
        <source>Layout Data</source>
        <translation type="vanished">Dados do layout</translation>
    </message>
    <message>
        <source>Layout name:</source>
        <translation type="vanished">Nome do layout:</translation>
    </message>
</context>
</TS>
